(function () {
    tinymce.PluginManager.add('millioneyez', function (editor, url) {

        var media = wp.media, shortcode_string = 'millioneyez', options = {}, toolbar, photoToolbar;
        wp.mce = wp.mce || {};

        initEditor();

        jQuery(window).on('message', function (e) {
            if (e && e.originalEvent && e.originalEvent.origin.substr(-'//curator.millioneyez.com'.length) == '//curator.millioneyez.com') {
                var message = JSON.parse(e.originalEvent.data);

                if (message.type == 'photobox' && message.missionId) {
                    var args = {
                        tag: shortcode_string,
                        type: 'closed',
                        attrs: {
                            missionid: message.missionId
                        }
                    };

                    editor.insertContent(wp.shortcode.string(args));
                }

                if (message.type == 'photo' && message.missionId && message.photoId) {
                    var args = {
                        tag: shortcode_string,
                        type: 'closed',
                        attrs: {
                            missionid: message.missionId,
                            photoid: message.photoId
                        }
                    };

                    editor.insertContent(wp.shortcode.string(args));
                }
            }
        });

        function isMillioneyezPlaceholder(elm) {
            if (elm && elm.nodeName == 'DIV') {
                var wpViewType = editor.dom.getAttrib(elm, 'data-wpview-type');
                return wpViewType == 'millioneyez';
            }
            return false;
        }

        function getPhotoboxId(node) {
            var result;
            try {
                result = node.innerText.match(/missionid="(.*?)"/)[1];
            } catch (e) {
                result = decodeURIComponent(jQuery(node.children[0]).attr("data-wpview-text") || jQuery(node).attr("data-wpview-text"));
                result = result.match(/missionid="(.*?)"/)[1];
            }
            return result;
        }

        function initEditor() {
            editor.addButton('millioneyez_pending', {
                tooltip: 'Pending',
                icon: 'dashicon dashicons-camera',
                onclick: function (e) {
                    var node = editor.selection.getNode();
                    var photoboxId = getPhotoboxId(node);
                    tb_show("Photobox", "//curator.millioneyez.com/editMission.html#/tab/" + photoboxId + "/?token=" + millioneyez.token + "&TB_iframe=true&modal=true&version=2.1.6");
                    editor.selection.setContent(editor.selection.getContent())
                }
            });
            editor.addButton('millioneyez_edit', {
                tooltip: 'Edit',
                icon: 'dashicon dashicons-edit',
                onclick: function (e) {
                    var node = editor.selection.getNode();
                    var photoboxId = getPhotoboxId(node);
                    tb_show("Edit", "//curator.millioneyez.com/editMission.html#/tab/" + photoboxId + "/edit?token=" + millioneyez.token + "&TB_iframe=true&modal=true&version=2.1.6");
                    editor.selection.setContent(editor.selection.getContent())
                }
            });

            editor.addButton('millioneyez_remove', {
                tooltip: 'Delete',
                icon: 'dashicon dashicons-no',
                onclick: function (e) {
                    var node = editor.selection.getNode();
                    var view = editor.wp.getView(node);

                    editor.undoManager.transact( function() {
                        editor.wp.setViewCursor(null, view);
                        wp.mce.views.remove(editor, view);
                    });
                }
            });

            // editor.addButton('millioneyez_upload', {
            //     tooltip: 'Upload',
            //     icon: 'dashicon dashicons-upload',
            //     onclick: function (e) {
            //         var node = editor.selection.getNode();
            //         var photoboxId = node.innerText.match(/"(.*?)"/g)[0];
            //         photoboxId = photoboxId.replace(new RegExp('"', 'g'),'');
            //         tb_show("Upload", "//curator.millioneyez.com/editMission.html#/tab/" + photoboxId + "/upload?token=" + millioneyez.token + "&TB_iframe=true&modal=true");
            //         editor.selection.setContent(editor.selection.getContent())
            //     }
            // });


            editor.once('preinit', function () {
                var removeHandler = editor && editor.wp && editor.wp.setViewCursor ? 'millioneyez_remove' : 'wp_view_remove';
                toolbar = editor.wp._createToolbar([
                    'millioneyez_pending',
                    'millioneyez_edit',
                    removeHandler,
                    'millioneyez_upload'
                ], true);
                photoToolbar = editor.wp._createToolbar([
                    'wp_view_remove'
                ], true);

                editor.on('wptoolbar', function (event) {
                    if (isMillioneyezPlaceholder(event.element)) {
                        if (this.dom.getAttrib(event.element,'data-wpview-text').indexOf('photoid') > -1) {
                            event.toolbar = photoToolbar;
                        } else {
                            event.toolbar = toolbar;
                        }
                    }
                });
            });

        }

        wp.mce.millioneyez_placeholder = {
            template: media.template('millioneyez-placeholder'),
            photoTemplate: media.template('millioneyez-photo-placeholder'),
            getContent: function () {
                options.missionId = this.shortcode.attrs.named.missionid;
                options.url = url.substr(0, url.lastIndexOf('/'));
                options.pending_number = options.pending_number || 0;
                getData(this.shortcode.attrs.named.missionid);
                if (this.shortcode.attrs.named.photoid) {
                    options.photoId = this.shortcode.attrs.named.photoid;
                    return this.photoTemplate(options);
                } else {
                    return this.template(options);
                }
            },
            View: { // before WP 4.2:
                initialize: function (options) {
                    this.shortcode = options.shortcode;
                    wp.mce.millioneyez_placeholder.shortcode_data = this.shortcode;
                },
                getHtml: function () {
                    options.missionId = this.shortcode.attrs.named.missionid;
                    options.url = url.substr(0, url.lastIndexOf('/'));
                    options.pending_number = options.pending_number || 0;
                    getData(this.shortcode.attrs.named.missionid);
                    if (this.shortcode.attrs.named.photoid) {
                        options.photoId = this.shortcode.attrs.named.photoid;
                        return this.photoTemplate(options);
                    } else {
                        return this.template(options);
                    }
                }
            }
        };
        wp.mce.views.register(shortcode_string, wp.mce.millioneyez_placeholder);

        function getData(missionid) {
            if (!missionid) {
                return false;
            }
            jQuery.ajax({
                url: 'https://api_secure_prod.millioneyez.com/v1.0/publisher/getPhotoboxInfo/' + missionid + '?authorization=Bearer+' + millioneyez.token + '&version=2.1.6',
                type: 'GET',
                data: {},
                success: function (data) {
                    var documentContent = content_ifr.contentDocument ? content_ifr.contentDocument : content_ifr.document;
                    var topBarContent = jQuery(documentContent.body.getElementsByClassName('mePendingPhotobox'));
                    var badges = documentContent.body.getElementsByClassName('mePendingBadge');
                    options.pending_number = data.pendingPhotos;
                    if (badges.length > 0) {
                        for (var i = 0; i < badges.length; i++) {
                            badges[i].innerText = data.pendingPhotos;
                        }
                    }
                    if (data.photoboxLive == null) {
                        topBarContent.find('.mePhotoboxNotApprove').removeClass('hidden');
                    } else {
                        var pendingSpanCount;

                        if (data.photoboxLiveNumber == 0) {
                            topBarContent.find('.mePhotoboxNotApprove').addClass('hidden');
                            topBarContent.find('.meNoLivePhotos').removeClass('hidden');
                        } else {
                            topBarContent.find('.mePhotoboxLive').removeClass('hidden');
                            topBarContent.find('.meNoLivePhotos').addClass('hidden');
                            var featuredPhotos = jQuery(documentContent.body.getElementsByClassName('meHolder')).find('.meFeaturedPhoto[data-src]');
                            for(var i = 0; i< featuredPhotos.length; i++) {
                                var imgElm = jQuery(featuredPhotos[i]);
                                var newSrc = imgElm.attr('data-src')+"&refresh=" + Date.now();
                                imgElm.attr('src',newSrc);
                            }
                            jQuery(documentContent.body.getElementsByClassName('meHolder')).removeClass('meHolderShowDefault').addClass('meHolderShowFeaturedPhoto');
                        }
                    }
                }
            });
        }
    });
})();
